[Cryptech-Commits] [user/js/keywrap] branch master updated: Fix some misleading messages, and enable all tests.

git at cryptech.is git at cryptech.is
Wed Aug 15 21:20:44 UTC 2018


This is an automated email from the git hooks/post-receive script.

paul at psgd.org pushed a commit to branch master
in repository user/js/keywrap.

The following commit(s) were added to refs/heads/master by this push:
     new 5a96b9a  Fix some misleading messages, and enable all tests.
5a96b9a is described below

commit 5a96b9a1c664ee43e27631e326655dca818ab837
Author: Paul Selkirk <paul at psgd.org>
AuthorDate: Wed Aug 15 17:20:20 2018 -0400

    Fix some misleading messages, and enable all tests.
---
 src/tb/tb_keywrap.v | 24 ++++++++++++------------
 1 file changed, 12 insertions(+), 12 deletions(-)

diff --git a/src/tb/tb_keywrap.v b/src/tb/tb_keywrap.v
index 5a838a4..c28b5a6 100644
--- a/src/tb/tb_keywrap.v
+++ b/src/tb/tb_keywrap.v
@@ -39,7 +39,7 @@
 
 module tb_keywrap();
 
-  parameter DEBUG     = 1;
+  parameter DEBUG     = 0;
   parameter DUMP_TOP  = 0;
   parameter DUMP_CORE = 0;
 
@@ -513,9 +513,9 @@ module tb_keywrap();
 
       // Read and display the A registers.
       read_word(ADDR_A0);
-      $display("A0 after wrap: 0x%08x", read_data);
+      $display("A0 after unwrap: 0x%08x", read_data);
       read_word(ADDR_A1);
-      $display("A1 after wrap: 0x%08x", read_data);
+      $display("A1 after unwrap: 0x%08x", read_data);
 
       // Read and display the R blocks that has been processed.
       for (i = 0 ; i < 8 ; i = i + 1)
@@ -733,7 +733,7 @@ module tb_keywrap();
 
   //----------------------------------------------------------------
   // test_kwp_ad_128_2
   // Implements wrap test based on NIST KWP_AD 128 bit key with
   // 4096 bit plaintext.
   //----------------------------------------------------------------
   task test_kwp_ad_128_2;
@@ -900,10 +900,10 @@ module tb_keywrap();
       write_word(ADDR_A1, 32'hd7f8ad7d);
 
 
-      $display("* Contents of memory and dut before wrap processing:");
+      $display("* Contents of memory and dut before unwrap processing:");
       dump_mem(65);
 
       // Start wrapping and wait for wrap to complete.
       $display("* Trying to start processing.");
       write_word(ADDR_CTRL, 32'h00000002);
       #(2 * CLK_PERIOD);
@@ -911,16 +911,16 @@ module tb_keywrap();
       $display("* Processing should be done.");
 
 
-      $display("Contents of memory and dut after wrap processing:");
+      $display("Contents of memory and dut after unwrap processing:");
       dump_mem(65);
       dump_dut_state();
 
 
       // Read and display the A registers.
       read_word(ADDR_A0);
-      $display("A0 after wrap: 0x%08x", read_data);
+      $display("A0 after unwrap: 0x%08x", read_data);
       read_word(ADDR_A1);
-      $display("A1 after wrap: 0x%08x", read_data);
+      $display("A1 after unwrap: 0x%08x", read_data);
 
       // Read and display the R blocks that has been processed.
       for (i = 0 ; i < 128 ; i = i + 1)
@@ -949,9 +949,9 @@ module tb_keywrap();
       reset_dut();
       dump_dut_state();
 
-//      test_kwp_ae_128_1();
-//      test_kwp_ad_128_1();
-//      test_kwp_ae_128_2();
+      test_kwp_ae_128_1();
+      test_kwp_ad_128_1();
+      test_kwp_ae_128_2();
       test_kwp_ad_128_2();
 
       display_test_results();
@@ -733,7 +733,7 @@ module tb_keywrap();
   //----------------------------------------------------------------
   // test_kwp_ad_128_2
-  // Implements wrap test based on NIST KWP_AD 128 bit key with
+  // Implements unwrap test based on NIST KWP_AD 128 bit key with
   // 4096 bit plaintext.
   //----------------------------------------------------------------
@@ -900,10 +900,10 @@ module tb_keywrap();
       dump_mem(65);
 
-      // Start wrapping and wait for wrap to complete.
+      // Start unwrapping and wait for unwrap to complete.
       $display("* Trying to start processing.");
       write_word(ADDR_CTRL, 32'h00000002);

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the Commits mailing list